import { BlockEditorState } from '@dotcms/uve/internal';
import { Block } from '@dotcms/uve/types';
import { DynamicComponentEntity } from '../../models';
import * as i0 from "@angular/core";
/**
 * Represents a Custom Renderer used by the Block Editor Component
 *
 * @export
 * @interface CustomRenderer
 */
export type CustomRenderer = Record<string, DynamicComponentEntity>;
/**
 * A component that renders content from DotCMS's Block Editor field.
 *
 * This component provides an easy way to render Block Editor content in your Angular applications.
 * It handles the rendering of standard blocks and allows customization through custom renderers.
 *
 * For more information about Block Editor, see {@link https://dev.dotcms.com/docs/block-editor}
 *
 * @example
 * ```html
 * <dotcms-block-editor-renderer
 *   [blocks]="myBlockEditorContent"
 *   [customRenderers]="myCustomRenderers">
 * </dotcms-block-editor-renderer>
 * ```
 */
export declare class DotCMSBlockEditorRendererComponent {
    blocks: Block;
    customRenderers: CustomRenderer | undefined;
    $blockEditorState: import("@angular/core").WritableSignal<BlockEditorState>;
    $isInEditMode: import("@angular/core").WritableSignal<boolean>;
    ngOnInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DotCMSBlockEditorRendererComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DotCMSBlockEditorRendererComponent, "dotcms-block-editor-renderer", never, { "blocks": { "alias": "blocks"; "required": false; }; "customRenderers": { "alias": "customRenderers"; "required": false; }; }, {}, never, never, true, never>;
}
//# sourceMappingURL=dotcms-block-editor-renderer.component.d.ts.map